@@ -1,8 +1,11 @@
 //!Functions to calculate relative humidity in %/100
 
-use crate::{error_wrapper::InputError, mixing_ratio, vapour_pressure};
+use crate::{errors::InputError, mixing_ratio, vapour_pressure};
 use crate::Float;
 
+#[cfg(feature="debug")]
+use floccus_proc::logerr;
+
 ///Formula for computing relative humidity from mixing ratio and saturation mixing ratio.
 ///Can be used interchangeably with [`general2`].
 ///
@@ -14,6 +17,7 @@ use crate::Float;
 ///Returns [`InputError::OutOfRange`] when one of inputs is out of range.\
 ///Valid `mixing_ratio` range: 0.00001 - 0.5\
 ///Valid `saturation_mixing_ratio` range: 0.00001 - 0.5
+#[cfg_attr(feature = "debug", logerr)]
 pub fn general1(mixing_ratio: Float, saturation_mixing_ratio: Float) -> Result<Float, InputError> {
     if !(0.00001..=10.0).contains(&mixing_ratio) {
         return Err(InputError::OutOfRange(String::from("mixing_ratio")));
@@ -36,6 +40,7 @@ pub fn general1(mixing_ratio: Float, saturation_mixing_ratio: Float) -> Result<F
 ///Returns [`InputError::OutOfRange`] when one of inputs is out of range.\
 ///Valid `vapour_pressure` range: 0Pa - 10000Pa
 ///Valid `saturation_vapour_pressure` range: 0Pa - 10000Pa
+#[cfg_attr(feature = "debug", logerr)]
 pub fn general2(vapour_pressure: Float, saturation_vapour_pressure: Float) -> Result<Float, InputError> {
     if !(0.0..=50_000.0).contains(&vapour_pressure) {
         return Err(InputError::OutOfRange(String::from("vapour_pressure")));
@@ -58,6 +63,7 @@ pub fn general2(vapour_pressure: Float, saturation_vapour_pressure: Float) -> Re
 ///Returns [`InputError::OutOfRange`] when one of inputs is out of range.\
 ///Valid `temperature` range: 273K - 353K
 ///Valid `dewpoint` range: 273K - 353K
+#[cfg_attr(feature = "debug", logerr)]
 pub fn general3(temperature: Float, dewpoint: Float) -> Result<Float, InputError> {
     if !(273.0..=353.0).contains(&temperature) {
         return Err(InputError::OutOfRange(String::from("temperature")));
@@ -83,6 +89,7 @@ pub fn general3(temperature: Float, dewpoint: Float) -> Result<Float, InputError
 ///Valid `temperature` range: 253K - 324K\
 ///Valid `dewpoint` range: 253K - 324K\
 ///Valid `pressure` range: 100Pa - 150000Pa
+#[cfg_attr(feature = "debug", logerr)]
 pub fn general4(temperature: Float, dewpoint: Float, pressure: Float) -> Result<Float, InputError> {
     if !(253.0..=324.0).contains(&temperature) {
         return Err(InputError::OutOfRange(String::from("temperature")));
@@ -112,6 +119,7 @@ pub fn general4(temperature: Float, dewpoint: Float, pressure: Float) -> Result<
 ///Valid `temperature` range: 232K - 324K\
 ///Valid `dewpoint` range: 232K - 324K\
 ///Valid `pressure` range: 100Pa - 150000Pa
+#[cfg_attr(feature = "debug", logerr)]
 pub fn general5(temperature: Float, dewpoint: Float, pressure: Float) -> Result<Float, InputError> {
     if !(232.0..=314.0).contains(&temperature) {
         return Err(InputError::OutOfRange(String::from("temperature")));
